==> mozc_0.12.410.102.orig.tar.gz: mozc-0.12.410.102/base/protobuf/protobuf.h <==
// Copyright 2010, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_BASE_PROTOBUF_PROTOBUF_H_
#define MOZC_BASE_PROTOBUF_PROTOBUF_H_

#define MOZC_TYPEDEF_PROTOBUF(name)             \
  namespace google {                            \
  namespace protobuf {                          \
  class name;                                   \
  }  /* namespace protobuf */                   \
  }  /* namespace google */                     \
  namespace mozc {                              \
  namespace protobuf {                          \
  typedef google::protobuf::name name;          \
  }  /* namespace protobuf */                   \
  }  /* namespace mozc */


// Typedef declarations.
MOZC_TYPEDEF_PROTOBUF(Message);
MOZC_TYPEDEF_PROTOBUF(Reflection);
MOZC_TYPEDEF_PROTOBUF(FieldDescriptor);

#undef MOZC_TYPEDEF_PROTOBUF

#endif  // MOZC_BASE_PROTOBUF_PROTOBUF_H_

==> mozc_1.0.558.102.orig.tar.gz: mozc-1.0.558.102/base/protobuf/protobuf.h <==
// Copyright 2010, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_BASE_PROTOBUF_PROTOBUF_H_
#define MOZC_BASE_PROTOBUF_PROTOBUF_H_

#define MOZC_TYPEDEF_PROTOBUF(name)             \
  namespace google {                            \
  namespace protobuf {                          \
  class name;                                   \
  }  /* namespace protobuf */                   \
  }  /* namespace google */                     \
  namespace mozc {                              \
  namespace protobuf {                          \
  typedef google::protobuf::name name;          \
  }  /* namespace protobuf */                   \
  }  /* namespace mozc */

#define MOZC_TYPEDEF_PROTOBUF_IO(name)          \
  namespace google {                            \
  namespace protobuf {                          \
  namespace io {                                \
  class name;                                   \
  }  /* namespace io */                         \
  }  /* namespace protobuf */                   \
  }  /* namespace google */                     \
  namespace mozc {                              \
  namespace protobuf {                          \
  namespace io {                                \
  typedef google::protobuf::io::name name;      \
  }  /* namespace io */                         \
  }  /* namespace protobuf */                   \
  }  /* namespace mozc */


// Typedef declarations.
MOZC_TYPEDEF_PROTOBUF(Message);
MOZC_TYPEDEF_PROTOBUF(Reflection);
MOZC_TYPEDEF_PROTOBUF(FieldDescriptor);
MOZC_TYPEDEF_PROTOBUF(TextFormat);
MOZC_TYPEDEF_PROTOBUF_IO(IstreamInputStream);

#undef MOZC_TYPEDEF_PROTOBUF
#undef MOZC_TYPEDEF_PROTOBUF_IO

#endif  // MOZC_BASE_PROTOBUF_PROTOBUF_H_
